# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

* [`local_rpm_repo`](#local_rpm_repo): Creates and hosts the specified RPM repositories.

**Defined types**

* [`local_rpm_repo::puppet_source`](#local_rpm_repopuppet_source): Repo with rpm files sourced from a puppet file server.
* [`local_rpm_repo::tar_source`](#local_rpm_repotar_source): Repo with instance data retrieve from a tar file.

## Classes

### local_rpm_repo

A simple class to create and manage locally maintained repositories using
tar file containing the RPMs.

#### Examples

##### Definition of three repositories

```puppet
class { 'local_rpm_repo':
  base_url_default => 'http://bin.example.com/data/',
  mirror_fqdn      => 'yum.example.com',
  repo_list        => {
    'repo1' => { version => '1.0.0.0' },
    'repo2' => { version => '1.0.0.0' },
    'repo3' => { version => '1.0.0.0' },
  },
}
```

#### Parameters

The following parameters are available in the `local_rpm_repo` class.

##### `mirror_fqdn`

Data type: `Stdlib::Fqdn`

Fully Qualified Domain Name which will be used as the apache vhost name on
this server. Note that this FQDN should resolve to this server.

##### `base_url_default`

Data type: `Optional[Local_rpm_repo::SourceUrl]`

This specifies the URL from which the repo tar should be extracted or the
remote files should be replicated if a specific url is not provided in
repo_list. When used, the application assumes the source data is located
within the specified directory.

For example, given a repo named 'test-repo' at version '1.0.5.1':
  * `http://bin.example.org/data` - expects http://bin.example.org/data/test-repo-1.0.5.1.tar to exist
  * `puppet:///repo_files` - expects the folder structure 'puppet:///repo_files/test-repo/1.0.5.1'

##### `repo_base_path`

Data type: `Stdlib::AbsolutePath`

Absolute path to the parent directory of the yum repository

Default value: '/var/yumrepos'

##### `repo_base_cache_path`

Data type: `Stdlib::AbsolutePath`

Absolute path to the parent directory of the yum repository cache
directory.

Default value: '/var/cache/yumrepos'

##### `repo_list`

Data type: `Hash[String, Local_rpm_repo::RepoData]`

A hash where the keys are the names of the repos to be deployed. The
following options are supported for each repo:
* version        - version of the source repo file
* source_prefix  - prefix of the file, defaults to the repo name.

@note At least one repository must be specified

Default value: {}

##### `suppress_cron_stdout`

Data type: `Boolean`

When enabled stdout generated by the createrepo command(s) will be directed
to `/dev/null`. This is very helpful if these messages would be emailed
unnecessarily in your environment.

Default value: `true`

## Defined types

### local_rpm_repo::puppet_source

This type is an implementation detail and should not be declared directly!

#### Parameters

The following parameters are available in the `local_rpm_repo::puppet_source` defined type.

##### `version`

Data type: `Local_rpm_repo::Version`

Version number to instantiate.

##### `base_url`

Data type: `Local_rpm_repo::PuppetUrl`

Puppet path to the RPM directory. See the repo::base_url_default for
further details.

##### `prefix`

Data type: `String`

String prepended to the version number to determine the source tar file
name. Note that this field is a namevar.

Default value: $name

##### `versions_path`

Data type: `Stdlib::AbsolutePath`

Absolute path to the versions subdirectory for this repository.

### local_rpm_repo::tar_source

This type is an implementation detail and should not be declared directly!

#### Parameters

The following parameters are available in the `local_rpm_repo::tar_source` defined type.

##### `version`

Data type: `Local_rpm_repo::Version`

Version number to instantiate.

##### `base_url`

Data type: `Variant[Stdlib::Httpurl, Stdlib::Httpsurl]`

Location containing the source tar file. See the repo::base_url_default for
further details.

##### `prefix`

Data type: `String`

String prepended to the version number to determine the source tar file
name. Note that this field is a namevar.

Default value: $name

##### `versions_path`

Data type: `Stdlib::AbsolutePath`

Absolute path to the versions subdirectory for this repository.

